using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Xml.Linq;
using SIS.Contracts.ConfigRepository;
using SIS.Contracts.PersonRepository;
using SIS.Infrastructure;
using SIS.Model;
using System.Drawing;

namespace SIS.PersonRepository
{
    public class MyPersonRepository: IPersonRepository
    {
        private readonly IConfigRepository _configRepository;

        public MyPersonRepository(IConfigRepository configRepository)
        {
            _configRepository = configRepository;
        }

        public IQueryable<Person> GetPersons()
        {
            XDocument doc = XDocument.Load(_configRepository.PersonsFilePath);

            var q = from p in doc.Descendants("Person")
                    select new Person() {Id = p.Element("ID").Value, 
                        Firstname = p.Element("Firstname").Value, 
                        Lastname = p.Element("Lastname").Value,
                        Company = p.Element("Company").Value
                    };

            return loadPersonPictures(q);
        }
        
        private IQueryable<Person> loadPersonPictures(IEnumerable<Person> q)
        {
            var list =  q.ToList();

            foreach (var person in list)
            {
                string file = Path.Combine(_configRepository.PictureFilePath, person.Id + ".jpg");

                if( File.Exists(file))
                {
                     
                    Image img = Image.FromFile( file);

                    person.Image = Helper.Serialize<Image>(img);    
                }
            }

            return list.AsQueryable();
        }

       
    }
}