using System;
using System.Windows;
using Microsoft.Practices.Composite.Modularity;
using Microsoft.Practices.Composite.UnityExtensions;
using SIS.Contracts.Shell;

namespace SIS
{
    public class SisBootstrapper: UnityBootstrapper 
    {
        
        protected override DependencyObject CreateShell()
        {
            var shellPresenter = Container.Resolve<IShellPresenter>();
            var view = shellPresenter.View;
            view.ShowView();

            return view as DependencyObject;
        }

        protected override void ConfigureContainer()
        {
            base.ConfigureContainer();

            Container.RegisterType<IShellView, ShellView>();
            Container.RegisterType<IShellPresenter, SIS.Shell.ShellPresenter>();

            Container.RegisterType<SIS.Contracts.ConfigRepository.IConfigRepository, SIS.ConfigRepository.AppConfigRepository >();

            Container.RegisterType<SIS.Contracts.PersonRepository.IPersonRepository, SIS.PersonRepository.MyPersonRepository>();
            
            Container.RegisterType<SIS.Contracts.PersonService.IPersonService, SIS.PersonService.MyPersonService>();

            Container.RegisterType<SIS.Contracts.PersonListModul.IPersonListModul, SIS.PersonListModul.PersonListModul>();
            Container.RegisterType<SIS.Contracts.PersonListModul.IPersonListController, SIS.PersonListModul.PersonListController >();
            Container.RegisterType<SIS.Contracts.PersonListModul.IPersonListView, SIS.PersonListModul.PersonListView>();
            Container.RegisterType<SIS.Contracts.PersonListModul.IPersonListViewModel, SIS.PersonListModul.PersonListViewModel>();
            
            Container.RegisterType<SIS.Contracts.PersonDetailsModul.IPersonDetailsModul, SIS.PersonDetailsModul.PersonDetailsModul>();
            Container.RegisterType<SIS.Contracts.PersonDetailsModul.IPersonDetailsController, SIS.PersonDetailsModul.PersonDetailsController>();
            Container.RegisterType<SIS.Contracts.PersonDetailsModul.IPersonDetailsView, SIS.PersonDetailsModul.PersonDetailsView>();
            Container.RegisterType<SIS.Contracts.PersonDetailsModul.IPersonDetailsViewModel, SIS.PersonDetailsModul.PersonDetailsViewModel>();
           
        }

        protected override Microsoft.Practices.Composite.Modularity.IModuleCatalog GetModuleCatalog()
        {
            return new ModuleCatalog()
                .AddModule(typeof(SIS.Contracts.PersonListModul.IPersonListModul))
                .AddModule(typeof(SIS.Contracts.PersonDetailsModul.IPersonDetailsModul));

            
        }
    }
}